==> estats_client-0.1.2-py3-none-any.whl: estats_client/__init__.py <==
"""
estats-client

A Python client library for the e-Stat API.
"""

__version__ = "0.1.2" # pyproject.tomlと同期させる

from .models.client import (
    EstatsAPIClient,
    StatsListParam,
    MetaInfoParam,
    StatsDataParam,
    Language,
    DataFormat,
)
from .models.result import (
    ResultInfo as StatsDataResultInfo,
    Parameter as StatsDataParameter,
    StatName as StatsDataStatName,
    GovOrg as StatsDataGovOrg,
    Title as StatsDataTitle,
    Category as StatsDataCategory,
    TableInfo as StatsDataTableInfo,
    Class as StatsDataClass,
    ClassObj as StatsDataClassObj,
    ClassInfo as StatsDataClassInfo,
    Note as StatsDataNote,
    Annotation as StatsDataAnnotation,
    Value as StatsDataValue,
    DataInfo as StatsDataDataInfo,
    ResultInf as StatsDataResultInf,
    StatisticalData,
    GetStatsData,
    GetStatsDataResponse,
)
from .models.result_get_catalog import (
    ResultInfo as CatalogResultInfo,
    Parameter as CatalogParameter,
    ResultInf as CatalogResultInf,
    StatName as CatalogStatName,
    Organization as CatalogOrganization,
    Title as CatalogTitle,
    Dataset as CatalogDataset,
    ResourceTitle as CatalogResourceTitle,
    Resource as CatalogResource,
    Resources as CatalogResources,
    DataCatalogInf,
    DataCatalogListInf,
    GetDataCatalog,
    GetDataCatalogResponse,
)

# catalog.py の関数は、クライアントのメソッドとして再設計するか、
# 別途ユーティリティとして提供するか検討後のため、一旦コメントアウト
# from .models.catalog import get_all_catalog, get_stats_list_with_retry


__all__ = [
    # client models
    "EstatsAPIClient",
    "StatsListParam",
    "MetaInfoParam",
    "StatsDataParam",
    "Language",
    "DataFormat",
    # result (getStatsData) models
    "GetStatsDataResponse",
    "GetStatsData",
    "StatisticalData",
    "StatsDataResultInfo",
    "StatsDataParameter",
    "StatsDataTableInfo",
    "StatsDataStatName", # result.py由来のStatName
    "StatsDataGovOrg",
    "StatsDataTitle",    # result.py由来のTitle
    "StatsDataCategory",
    "StatsDataClassInfo",
    "StatsDataClassObj",
    "StatsDataClass",
    "StatsDataDataInfo",
    "StatsDataNote",
    "StatsDataAnnotation",
    "StatsDataValue",
    "StatsDataResultInf", # result.py由来のResultInf
    # result_get_catalog (getStatsList/getDataCatalog) models
    "GetDataCatalogResponse",
    "GetDataCatalog",
    "DataCatalogListInf",
    "DataCatalogInf",
    "CatalogResultInfo",
    "CatalogParameter",
    "CatalogResultInf", # result_get_catalog.py由来のResultInf
    "CatalogStatName",  # result_get_catalog.py由来のStatName
    "CatalogOrganization",
    "CatalogTitle",     # result_get_catalog.py由来のTitle
    "CatalogDataset",
    "CatalogResourceTitle",
    "CatalogResource",
    "CatalogResources",
    # "get_all_catalog",
    # "get_stats_list_with_retry",
]

==> estats_client-0.1.3-py3-none-any.whl: estats_client/__init__.py <==
"""estats-client.

A Python client library for the e-Stat API.
"""

__version__ = "0.1.3"

from .client import (
    DataFormat,
    EstatsAPIClient,
    Language,
    MetaInfoParam,
    StatsDataParam,
    StatsListParam,
)
from .models.result import (
    Annotation as StatsDataAnnotation,
)
from .models.result import (
    Category as StatsDataCategory,
)
from .models.result import (
    Class as StatsDataClass,
)
from .models.result import (
    ClassInfo as StatsDataClassInfo,
)
from .models.result import (
    ClassObj as StatsDataClassObj,
)
from .models.result import (
    DataInfo as StatsDataDataInfo,
)
from .models.result import (
    GetStatsData,
    GetStatsDataResponse,
    StatisticalData,
)
from .models.result import (
    GovOrg as StatsDataGovOrg,
)
from .models.result import (
    Note as StatsDataNote,
)
from .models.result import (
    Parameter as StatsDataParameter,
)
from .models.result import (
    ResultInf as StatsDataResultInf,
)
from .models.result import (
    ResultInfo as StatsDataResultInfo,
)
from .models.result import (
    StatName as StatsDataStatName,
)
from .models.result import (
    TableInfo as StatsDataTableInfo,
)
from .models.result import (
    Title as StatsDataTitle,
)
from .models.result import (
    Value as StatsDataValue,
)
from .models.result_get_catalog import (
    DataCatalogInf,
    DataCatalogListInf,
    GetDataCatalog,
    GetDataCatalogResponse,
)
from .models.result_get_catalog import (
    Dataset as CatalogDataset,
)
from .models.result_get_catalog import (
    Organization as CatalogOrganization,
)
from .models.result_get_catalog import (
    Parameter as CatalogParameter,
)
from .models.result_get_catalog import (
    Resource as CatalogResource,
)
from .models.result_get_catalog import (
    Resources as CatalogResources,
)
from .models.result_get_catalog import (
    ResourceTitle as CatalogResourceTitle,
)
from .models.result_get_catalog import (
    ResultInf as CatalogResultInf,
)
from .models.result_get_catalog import (
    ResultInfo as CatalogResultInfo,
)
from .models.result_get_catalog import (
    StatName as CatalogStatName,
)
from .models.result_get_catalog import (
    Title as CatalogTitle,
)

__all__ = [
    "EstatsAPIClient",
    "StatsListParam",
    "MetaInfoParam",
    "StatsDataParam",
    "Language",
    "DataFormat",
    "GetStatsDataResponse",
    "GetStatsData",
    "StatisticalData",
    "StatsDataResultInfo",
    "StatsDataParameter",
    "StatsDataTableInfo",
    "StatsDataStatName",
    "StatsDataGovOrg",
    "StatsDataTitle",
    "StatsDataCategory",
    "StatsDataClassInfo",
    "StatsDataClassObj",
    "StatsDataClass",
    "StatsDataDataInfo",
    "StatsDataNote",
    "StatsDataAnnotation",
    "StatsDataValue",
    "StatsDataResultInf",
    "GetDataCatalogResponse",
    "GetDataCatalog",
    "DataCatalogListInf",
    "DataCatalogInf",
    "CatalogResultInfo",
    "CatalogParameter",
    "CatalogResultInf",
    "CatalogStatName",
    "CatalogOrganization",
    "CatalogTitle",
    "CatalogDataset",
    "CatalogResourceTitle",
    "CatalogResource",
    "CatalogResources",
]
